import os
from qgis.core import *

class GeometryErrors(object):

    def __init__(self, errorsGeometries):
        super(GeometryErrors, self).__init__()

        self.__errorsGeometries = errorsGeometries

    @property
    def errorsGeometries(self):
        return self.__errorsGeometries


class ErrorShapefile(object):

    _GEOMTYPE = {0: "Point", 1: "LineString", 2: "Polygon"}
    _FIELDS = {"descr": "string"}
    _PROVIDER = "memory"

    def __init__(self, geomType, crs):
        super(ErrorShapefile, self).__init__()

        self.__crs = crs
        self.__geomType = int(geomType)
        self.__shapefile = QgsVectorLayer(self.creationString, self.layerName, self.provider)

    @property
    def geomType(self):
        return self.__geomType

    @property
    def crs(self):
        return self.__crs

    @property
    def creationString(self):
        string = "%s?crs=epsg:%d" % (self.layerName, self.crs)
        for fieldName, fieldType in ErrorShapefile._FIELDS.items():
            string += "&field=%s:%s" % (fieldName, fieldType)
        string += "&index=yes"
        return string

    @property
    def layerName(self):
        return ErrorShapefile._GEOMTYPE[self.geomType]

    @property
    def provider(self):
        return ErrorShapefile._PROVIDER

    @property
    def shapefile(self):
        return self.__shapefile

    def addFeature(self, feature):
        pr = self.shapefile.dataProvider()
        geom, descr = feature
        feat = QgsFeature()
        if self.geomType == 0:
            feat.setGeometry(QgsGeometry.fromPoint(QgsPoint(geom[0], geom[1])))
        else:
            feat.setGeometry(geom)
        feat.setAttributes([descr])
        pr.addFeatures([feat])
        self.shapefile.updateExtents()
